@@ -35,10 +35,6 @@ class PropertyControllerClient : public PropertyControllerInterface
   public:
     explicit PropertyControllerClient(const QString &name, QObject *parent = 0);
     virtual ~PropertyControllerClient();
-
-  public slots:
-    virtual void activateMethod();
-    virtual void invokeMethod(Qt::ConnectionType type);
 };
 
 }
