@@ -40,6 +40,7 @@
 #include "remote/remotemodelserver.h"
 #include "remote/selectionmodelserver.h"
 #include "toolpluginerrormodel.h"
+#include "toolfactory.h"
 
 #include <common/objectbroker.h>
 #include <common/streamoperators.h>
@@ -108,6 +109,7 @@ void dumpObject(QObject *obj)
     return;
   }
 
+  const std::ios::fmtflags oldFlags(cout.flags());
   do {
     cout << obj->metaObject()->className() << "(" << hex << obj << ")";
     obj = obj->parent();
@@ -116,6 +118,7 @@ void dumpObject(QObject *obj)
     }
   } while(obj);
   cout << endl;
+  cout.flags(oldFlags);
 }
 
 struct Listener
@@ -175,6 +178,8 @@ Probe::Probe(QObject *parent):
   registerModel(QLatin1String("com.kdab.GammaRay.ToolModel"), m_toolModel);
   registerModel(QLatin1String("com.kdab.GammaRay.ConnectionModel"), m_connectionModel);
 
+  m_toolSelectionModel = ObjectBroker::selectionModel(m_toolModel);
+
   ToolPluginModel *toolPluginModel = new ToolPluginModel(m_toolModel->plugins(), this);
   registerModel(QLatin1String("com.kdab.GammaRay.ToolPluginModel"), toolPluginModel);
   ToolPluginErrorModel *toolPluginErrorModel = new ToolPluginErrorModel(m_toolModel->pluginErrors(), this);
@@ -269,6 +274,8 @@ void Probe::createProbe(bool findExisting)
   s_listener()->filterThread = 0;
   IF_DEBUG(cout << "done setting up new probe instance" << endl;)
 
+  connect(qApp, SIGNAL(aboutToQuit()), probe, SLOT(deleteLater()));
+
   // now we can get the lock and add items which where added before this point in time
   {
     QWriteLocker lock(s_lock());
@@ -739,6 +746,17 @@ bool Probe::hasReliableObjectTracking() const
 void Probe::selectObject(QObject* object, const QPoint& pos)
 {
   emit objectSelected(object, pos);
+
+  m_toolSelectionModel->select( m_toolModel->toolForObject(object), QItemSelectionModel::Select | QItemSelectionModel::Clear |
+    QItemSelectionModel::Rows | QItemSelectionModel::Current);
+}
+
+void Probe::selectObject(void* object, const QString& typeName)
+{
+  emit nonQObjectSelected(object, typeName);
+
+  m_toolSelectionModel->select( m_toolModel->toolForObject(object, typeName), QItemSelectionModel::Select | QItemSelectionModel::Clear |
+    QItemSelectionModel::Rows | QItemSelectionModel::Current);
 }
 
 //BEGIN: SignalSlotsLocationStore
