@@ -25,25 +25,18 @@
 #define GAMMARAY_PROPERTYCONTROLLER_H
 
 #include "gammaray_core_export.h"
+#include "propertycontrollerextension.h"
 
 #include <common/propertycontrollerinterface.h>
 
 #include <QPointer>
+#include <QVector>
 
 class QAbstractItemModel;
-class QStandardItemModel;
 
 namespace GammaRay {
 
 class ConnectionFilterProxyModel;
-class MultiSignalMapper;
-class ObjectDynamicPropertyModel;
-class ObjectStaticPropertyModel;
-class ObjectClassInfoModel;
-class ObjectMethodModel;
-class ObjectEnumModel;
-class MetaPropertyModel;
-class MethodArgumentModel;
 
 /** @brief Non-UI part of the property widget. */
 class GAMMARAY_CORE_EXPORT PropertyController : public PropertyControllerInterface
@@ -54,37 +47,37 @@ public:
   explicit PropertyController(const QString &baseName, QObject *parent);
   ~PropertyController();
 
+  const QString &objectBaseName();
+
   void setObject(QObject *object);
   void setObject(void *object, const QString &className);
   void setMetaObject(const QMetaObject *metaObject);
 
-public slots:
-  void activateMethod();
-  void invokeMethod(Qt::ConnectionType type);
+  void registerModel(QAbstractItemModel *model, const QString &nameSuffix);
+
+  template<typename T>
+  static void registerExtension()
+  {
+    PropertyControllerExtensionFactoryBase *factory = new PropertyControllerExtensionFactory<T>();
+    s_extensionFactories << factory;
+    foreach (PropertyController *instance, s_instances)
+      instance->loadExtension(factory);
+  }
 
 private slots:
-  void signalEmitted(QObject *sender, int signalIndex, const QVector<QVariant> &args);
   void objectDestroyed();
 
 private:
-  void registerModel(QAbstractItemModel *model, const QString &nameSuffix);
+  void loadExtension(PropertyControllerExtensionFactoryBase *factory);
 
 private:
   QString m_objectBaseName;
 
   QPointer<QObject> m_object;
-  ObjectStaticPropertyModel *m_staticPropertyModel;
-  ObjectDynamicPropertyModel *m_dynamicPropertyModel;
-  ObjectClassInfoModel *m_classInfoModel;
-  ObjectMethodModel *m_methodModel;
-  ConnectionFilterProxyModel *m_inboundConnectionModel;
-  ConnectionFilterProxyModel *m_outboundConnectionModel;
-  ObjectEnumModel *m_enumModel;
-  MultiSignalMapper *m_signalMapper;
-  QStandardItemModel *m_methodLogModel;
-  MetaPropertyModel *m_metaPropertyModel;
+  QVector<PropertyControllerExtension*> m_extensions;
 
-  MethodArgumentModel *m_methodArgumentModel;
+  static QVector<PropertyControllerExtensionFactoryBase*> s_extensionFactories;
+  static QVector<PropertyController*> s_instances;
 };
 
 }
