@@ -22,10 +22,9 @@
 */
 
 #include "metatypebrowser.h"
-
 #include "metatypesmodel.h"
 
-#include <common/objectbroker.h>
+#include "common/objectbroker.h"
 
 using namespace GammaRay;
 
