@@ -19,8 +19,8 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef GAMMARAY_STATEMACHINEVIEWERCLIENT_H
-#define GAMMARAY_STATEMACHINEVIEWERCLIENT_H
+#ifndef GAMMARAY_STATEMACHINEVIEWER_STATEMACHINEVIEWERCLIENT_H
+#define GAMMARAY_STATEMACHINEVIEWER_STATEMACHINEVIEWERCLIENT_H
 
 #include "statemachineviewerinterface.h"
 
